disabled compiler flag hcc 4.0 for half support

Change-Id: I32175113f4c05d43310b3a05c2a14e12f6d48b09
This commit is contained in:
Aditya Atluri
2016-12-13 20:06:56 -06:00
parent b30e4b4781
commit ed39a7f43b
2 changed files with 10 additions and 15 deletions
+10 -12
View File
@@ -27,7 +27,16 @@ THE SOFTWARE.
#define __CLANG_VERSION__ __clang_major__ * 10 + __clang_minor__
#if __CLANG_VERSION__ == 35
#ifdef HIP_HALF_HW_SUPPORT
typedef __fp16 __half;
extern "C" __half __hip_hadd_clang40_gfx803(__half a, __half b);
__device__ inline __half __hadd(__half a, __half b){
return __hip_hadd_clang40_gfx803(a, b);
}
#else
typedef struct{
unsigned x: 16;
@@ -178,16 +187,5 @@ __device__ __half2 __lowhigh2highlow(const __half2 a);
__device__ __half2 __low2half2(const __half2 a, const __half2 b);
#endif
#if __CLANG_VERSION__ == 40
typedef __fp16 __half;
extern "C" __half __hip_hadd_clang40_gfx803(__half a, __half b);
__device__ inline __half __hadd(__half a, __half b){
return __hip_hadd_clang40_gfx803(a, b);
}
#endif
#endif